/*
 *  tparser.h
 *
 *  Copyright  Daniel M. German
 *  
 *  April 2007
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This software is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this software; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *
 *  Author: Daniel M German dmgerman at uvic doooot ca
 * 
 */


/* Maximum size for an input token */
#define PARSER_MAX_LINE 1000
#define PT_TOKEN_MAX_LEN PARSER_MAX_LINE

/* 
 Data structure where the entire input file will be read 
*/

#define FALSE 0
#define TRUE  0


typedef struct {
    int width;
    int height;
    int projection;
    char *projectionParms;
    char *projectionName;
    float fHorFOV;
    char *outputFormat;
}  pt_script_pano;

typedef struct {
    int projection;
    int width;
    int height;
    float fHorFOV;
    float yaw;
    float pitch;
    float roll;
    float coef[7]; // a, b, c, d, e       , g, t
    char *name;
    int cropType ;
    int cropArea[4];
    int morphToFit;
    // pointers to variable if they are used.
    // For the sake of simplicity they start at 1, if they are zero they are unused
    int fHorFOVIndex;
    int yawIndex;
    int pitchIndex;
    int rollIndex;
    int coefIndex[7]; // a, b, c, d, e       , g, t
}  pt_script_image;

typedef struct {
    int iImage;
    float x1, y1, x2, y2;
} pt_script_morphing_points;

typedef struct {
    float fGamma;
    int interpolator;
    int fastFT;
    int humberEstimator;
} pt_script_optimize;

typedef struct {
    pt_script_pano pano;
    int iInputImagesCount;
    pt_script_image *inputImageSpec;
    int iOutputImagesCount;
    pt_script_image *outputImageSpec;
    pt_script_morphing_points *morphingPointsSpec;
    pt_script_optimize optimize;
}  pt_script;

pt_script *Read_Script(char *fileName);


void TokenBegin(char *t) ;
int  GetNextChar(char *b, int maxBuffer) ;
void Parse_Error(char const *errorstring, ...) ;



